@@ -6,9 +6,3 @@ vers <- paste(sessionInfo()$otherPkg$bipartite$Version,".",sep="")
 
 cat(paste("----------------------------------------------------------\nThis is bipartite",vers,"\nFor latest additions type: ?bipartite.\nFor citation please type: citation(\"bipartite\").\nHave a nice time plotting and analysing two-mode networks.\n----------------------------------------------------------\n\n"))
 }
-
-.Last.lib <- function() {
-
-  library.dynam.unload("bipartite", paste(.libPaths(),"/bipartite",sep=""))
-
-}
\ No newline at end of file
